@@ -50,7 +50,7 @@ impl Lints {
     /// # Panics
     ///
     /// Will panic if the lint prefix isn't delimited by dots. This should never happen as it's a constant
-    pub fn get_from_toml_or_else_vcs(config: &str, vcs: &mut dyn Vcs) -> Result<Lints, Error> {
+    pub fn read_from_toml_or_else_vcs(config: &str, vcs: &mut dyn Vcs) -> Result<Lints, Error> {
         let vcs_lints = Lints::try_from_vcs(vcs)?;
         // contains PB  // contains lint // contains config
         let config: BTreeMap<String, BTreeMap<String, BTreeMap<String, bool>>> =
@@ -193,7 +193,6 @@ mod tests {
     use std::convert::{TryFrom, TryInto};
 
     use indoc::indoc;
-    use pretty_assertions::assert_eq;
 
     use crate::lints::lib::lint::Lint::{
         BodyWiderThan72Characters, GitHubIdMissing, SubjectLongerThan72Characters,
@@ -213,7 +212,7 @@ mod tests {
         ];
         let actual: Result<Lints, Error> = lints.try_into();
 
-        assert_eq!(true, actual.is_err());
+        assert!(actual.is_err());
     }
 
     #[test]
@@ -303,7 +302,7 @@ mod tests {
         let mut store = BTreeMap::new();
         let mut vcs = InMemory::new(&mut store);
 
-        let actual = Lints::get_from_toml_or_else_vcs(
+        let actual = Lints::read_from_toml_or_else_vcs(
             indoc!(
                 "
                 "
@@ -368,7 +367,7 @@ mod tests {
         let mut store = BTreeMap::new();
         let mut vcs = InMemory::new(&mut store);
 
-        let actual = Lints::get_from_toml_or_else_vcs(
+        let actual = Lints::read_from_toml_or_else_vcs(
             indoc!(
                 "
                 [mit.lint]
@@ -399,7 +398,7 @@ mod tests {
         let mut store = BTreeMap::new();
         let mut vcs = InMemory::new(&mut store);
 
-        let actual = Lints::get_from_toml_or_else_vcs(
+        let actual = Lints::read_from_toml_or_else_vcs(
             indoc!(
                 "
                 [mit.lint]
